<?php
/**
 * Product Notes for WooCommerce - Functions
 *
 * @version 2.0.0
 * @since   1.1.3
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! function_exists( 'alg_wc_pn_get_enabled_sections' ) ) {
	/**
	 * alg_wc_pn_get_enabled_sections.
	 *
	 * @version 2.0.0
	 * @since   2.0.0
	 */
	function alg_wc_pn_get_enabled_sections() {
		$sections = array();
		foreach ( array( 'private', 'public' ) as $private_or_public ) {
			if ( 'yes' === get_option( "alg_wc_pn_{$private_or_public}_enabled", 'yes' ) ) {
				$sections[] = $private_or_public;
			}
		}
		return $sections;
	}
}

if ( ! function_exists( 'alg_wc_pn_is_any_section_enabled' ) ) {
	/**
	 * alg_wc_pn_is_any_section_enabled.
	 *
	 * @version 2.0.0
	 * @since   2.0.0
	 */
	function alg_wc_pn_is_any_section_enabled() {
		$sections = alg_wc_pn_get_enabled_sections();
		return ( ! empty( $sections ) );
	}
}

if ( ! function_exists( 'alg_wc_pn_get_product_notes' ) ) {
	/**
	 * alg_wc_pn_get_product_notes.
	 *
	 * @version 2.0.0
	 * @since   1.1.3
	 * @todo    [dev] (maybe) `$do_strip_tags`
	 */
	function alg_wc_pn_get_product_notes( $private_or_public, $product_id = 0, $args = array() ) {
		$notes = '';
		if ( function_exists( 'alg_wc_pn' ) ) {
			$args  = array_replace( array( 'do_esc_html' => true, 'glue' => PHP_EOL, 'do_wpautop' => true ), $args );
			$notes = alg_wc_pn()->core->get_product_note_values( $private_or_public, $product_id );
			$notes = ( $args['do_esc_html'] ? array_map( 'esc_html', $notes ) : $notes );
			$notes = implode( $args['glue'], $notes );
			$notes = ( $args['do_wpautop']  ? wpautop( $notes ) : $notes );
		}
		return $notes;
	}
}

if ( ! function_exists( 'alg_wc_product_notes_shortcode' ) ) {
	/**
	 * alg_wc_product_notes_shortcode.
	 *
	 * @version 2.0.0
	 * @since   1.1.3
	 */
	function alg_wc_product_notes_shortcode( $atts, $content = '' ) {
		$atts = shortcode_atts( array(
			'private_or_public' => 'public',
			'product_id'        => 0,
			'do_esc_html'       => true,
			'glue'              => PHP_EOL,
			'do_wpautop'        => true,
		), $atts, 'alg_wc_product_notes_shortcode' );
		return alg_wc_pn_get_product_notes( $atts['private_or_public'], $atts['product_id'], array(
			'do_esc_html' => filter_var( $atts['do_esc_html'], FILTER_VALIDATE_BOOLEAN ),
			'glue'        => $atts['glue'],
			'do_wpautop'  => filter_var( $atts['do_wpautop'],  FILTER_VALIDATE_BOOLEAN ),
		) );
	}
	add_shortcode( 'alg_wc_product_notes', 'alg_wc_product_notes_shortcode' );
}
