<?php
/**
 * Product Notes for WooCommerce - Display Class
 *
 * @version 2.1.0
 * @since   2.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Product_Notes_Display' ) ) :

class Alg_WC_Product_Notes_Display {

	/**
	 * Constructor.
	 *
	 * @version 2.1.0
	 * @since   2.0.0
	 * @todo    [dev] (maybe) add more frontend positions (i.e. not only Tab and Meta)
	 */
	function __construct() {
		// Frontend: Product tab
		add_filter( 'woocommerce_product_tabs',           array( $this, 'add_product_tabs' ) );
		// Frontend: Product meta
		add_action( 'woocommerce_product_meta_end',       array( $this, 'display_in_product_meta' ) );
	}

	/**
	 * display_in_product_meta.
	 *
	 * @version 2.0.0
	 * @since   2.0.0
	 * @todo    [dev] before/after (same in Tab)
	 * @todo    [dev] customizable position, i.e. `woocommerce_product_meta_start`
	 * @todo    [dev] (maybe) `wpautop` / `esc_html` / `glue` should be optional?
	 * @todo    [dev] (maybe) add date and author
	 */
	function display_in_product_meta() {
		global $product;
		foreach ( alg_wc_pn_get_enabled_sections() as $private_or_public ) {
			if ( 'yes' === get_option( "alg_wc_pn_{$private_or_public}_product_meta", 'no' ) ) {
				echo alg_wc_pn_get_product_notes( $private_or_public, $product->get_id(), array( 'do_esc_html' => false, 'glue' => '<br>', 'do_wpautop' => false ) );
			}
		}
	}

	/**
	 * add_product_tabs.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 * @todo    [dev] (next) customizable tab IDs
	 * @todo    [dev] (next) JS (i.e. when opened by link, tab should automatically open)
	 * @todo    [dev] (maybe) per product: tab id
	 * @todo    [dev] (maybe) per product: tab priority
	 * @todo    [dev] (maybe) per product: tab enable/disable
	 */
	function add_product_tabs( $tabs ) {
		global $product;
		foreach ( alg_wc_pn_get_enabled_sections() as $private_or_public ) {
			if ( 'yes' === get_option( "alg_wc_pn_{$private_or_public}_product_tab", 'yes' ) ) {
				if ( array() != ( $value = alg_wc_pn()->core->get_product_note_values( $private_or_public, $product->get_id() ) ) ) {
					if ( 'private' === $private_or_public && ! alg_wc_pn()->core->current_user_is_admin() ) {
						continue;
					}
					$tab_id               = ( 'private' === $private_or_public ? 'private_notes' : 'notes' );
					$default_tab_title    = ( 'private' === $private_or_public ? __( 'Private notes', 'product-notes-for-woocommerce' ) : __( 'Notes', 'product-notes-for-woocommerce' ) );
					$default_tab_priority = ( 'private' === $private_or_public ? 100 : 101 );
					$tab_title            = ( 'yes' === get_option( "alg_wc_pn_{$private_or_public}_product_tab_title_per_product", 'no' ) &&
						'' !== ( $tab_title_per_product = get_post_meta( $product->get_id(), alg_wc_pn()->get_id( $private_or_public ) . '_tab_title' , true ) ) ?
							$tab_title_per_product : get_option( "alg_wc_pn_{$private_or_public}_product_tab_title", $default_tab_title ) );
					$tabs[ $tab_id ] = array(
						'title'    => $tab_title,
						'priority' => get_option( "alg_wc_pn_{$private_or_public}_product_tab_priority", $default_tab_priority ),
						'callback' => array( $this, "display_product_tab_{$private_or_public}" ),
					);
				}
			}
		}
		return $tabs;
	}

	/**
	 * display_product_tab_private.
	 *
	 * @version 2.0.0
	 * @since   2.0.0
	 * @todo    [dev] (maybe) `wpautop` / `esc_html` / `glue` should be optional?
	 * @todo    [dev] (maybe) add date and author
	 */
	function display_product_tab_private() {
		global $product;
		echo alg_wc_pn_get_product_notes( 'private', $product->get_id(), array( 'do_esc_html' => true, 'glue' => PHP_EOL, 'do_wpautop' => true ) );
	}

	/**
	 * display_product_tab_public.
	 *
	 * @version 2.0.0
	 * @since   2.0.0
	 * @todo    [dev] (maybe) `wpautop` / `esc_html` / `glue` should be optional?
	 * @todo    [dev] (maybe) add date and author
	 */
	function display_product_tab_public() {
		global $product;
		echo alg_wc_pn_get_product_notes( 'public', $product->get_id(), array( 'do_esc_html' => true, 'glue' => PHP_EOL, 'do_wpautop' => true ) );
	}

}

endif;

return new Alg_WC_Product_Notes_Display();
