<?php
/**
 * Product Notes for WooCommerce - Section Settings
 *
 * @version 2.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Product_Notes_Settings_Section' ) ) :

class Alg_WC_Product_Notes_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 */
	function __construct( $id, $desc, $private_or_public ) {
		$this->id                = $id;
		$this->desc              = $desc;
		$this->private_or_public = $private_or_public;
		add_filter( 'woocommerce_get_sections_alg_wc_product_notes',              array( $this, 'settings_section' ) );
		add_filter( 'woocommerce_get_settings_alg_wc_product_notes_' . $this->id, array( $this, 'get_settings' ), PHP_INT_MAX );
	}

	/**
	 * settings_section.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function settings_section( $sections ) {
		$sections[ $this->id ] = $this->desc;
		return $sections;
	}

	/**
	 * get_section_settings.
	 *
	 * @version 2.1.0
	 * @since   2.0.0
	 * @todo    [dev] (maybe) store settings in array, i.e. `alg_wc_pn_{$private_or_public}[enabled]` etc.
	 */
	function get_settings() {

		$private_or_public = $this->private_or_public;

		switch ( $private_or_public ) {
			case 'private':
				$section_title        = __( 'Private Notes Options', 'product-notes-for-woocommerce' );
				$option_title         = __( 'Private notes', 'product-notes-for-woocommerce' );
				$frontend_desc        = '<strong>' . __( 'Private notes on frontend will be visible to admin and shop manager only.', 'product-notes-for-woocommerce' ) . '</strong>';
				$default_tab_title    = __( 'Private notes', 'product-notes-for-woocommerce' );
				$default_tab_priority = 100;
				break;
			case 'public':
				$section_title        = __( 'Public Notes Options', 'product-notes-for-woocommerce' );
				$option_title         = __( 'Public notes', 'product-notes-for-woocommerce' );
				$frontend_desc        = '';
				$default_tab_title    = __( 'Notes', 'product-notes-for-woocommerce' );
				$default_tab_priority = 101;
				break;
		}

		$general_settings = array(
			array(
				'title'    => $section_title,
				'type'     => 'title',
				'id'       => "alg_wc_pn_{$private_or_public}_general_options",
			),
			array(
				'title'    => $option_title,
				'desc'     => '<strong>' . __( 'Enable section', 'product-notes-for-woocommerce' ) . '</strong>',
				'id'       => "alg_wc_pn_{$private_or_public}_enabled",
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => "alg_wc_pn_{$private_or_public}_general_options",
			),
		);

		$frontend_settings = array(
			array(
				'title'    => __( 'Frontend Options', 'product-notes-for-woocommerce' ),
				'desc'     => $frontend_desc,
				'type'     => 'title',
				'id'       => "alg_wc_pn_{$private_or_public}_frontend_options",
			),
			array(
				'title'    => __( 'Product tab', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Show product notes in tab on frontend.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_product_tab",
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'desc'     => __( 'Tab title', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_product_tab_title",
				'default'  => $default_tab_title,
				'type'     => 'text',
			),
			array(
				'desc'     => __( 'Tab title per product', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_product_tab_title_per_product",
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'desc'     => __( 'Tab priority (i.e. position)', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_product_tab_priority",
				'default'  => $default_tab_priority,
				'type'     => 'number',
			),
			array(
				'title'    => __( 'Product meta', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Show product notes in product meta on frontend.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_product_meta",
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => "alg_wc_pn_{$private_or_public}_frontend_options",
			),
		);

		$backend_settings = array(
			array(
				'title'    => __( 'Backend Options', 'product-notes-for-woocommerce' ),
				'desc'     => apply_filters( 'alg_wc_pn_settings', sprintf( __( "You'll need %s plugin version for the disabled options.", 'product-notes-for-woocommerce' ),
					'<a href="https://wpfactory.com/item/product-notes-for-woocommerce/" target="_blank">' . __( 'Product Notes for WooCommerce Pro', 'product-notes-for-woocommerce' ) . '</a>' ) ),
				'type'     => 'title',
				'id'       => "alg_wc_pn_{$private_or_public}_backend_options",
			),
			array(
				'title'    => __( 'Textarea style', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( "Styling for the textarea input on product's admin edit page.", 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_textarea_style",
				'default'  => 'width:100%;height:150px;',
				'type'     => 'text',
				'css'      => 'width:100%',
			),
			array(
				'title'    => __( 'Admin products list column', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Show product notes in admin products list column.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_products_column",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Admin orders', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Show product notes in admin orders.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_admin_orders",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Admin emails', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Show product notes in admin emails.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_admin_emails",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Admin search', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Make product notes searchable by admin.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_admin_search",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'desc'     => __( 'JSON Search', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'This will also make products notes searchable in admin JSON, e.g. when searching for "Linked Products".', 'product-notes-for-woocommerce' ) . ' ' .
					__( '"Admin search" option must be enabled.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_admin_search_json",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Export', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Make product notes exportable in "Products > Export".', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_export",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Import', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Make product notes importable in "Products > Import".', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_import",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Quick edit', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Make product notes editable in "Quick Edit".', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_quick_edit",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Bulk edit', 'product-notes-for-woocommerce' ),
				'desc'     => __( 'Enable', 'product-notes-for-woocommerce' ),
				'desc_tip' => __( 'Make product notes editable in "Bulk Actions > Edit".', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_bulk_edit",
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_pn_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'type'     => 'sectionend',
				'id'       => "alg_wc_pn_{$private_or_public}_backend_options",
			),
		);

		$advanced_settings = array(
			array(
				'title'    => __( 'Advanced Options', 'product-notes-for-woocommerce' ),
				'type'     => 'title',
				'id'       => "alg_wc_pn_{$private_or_public}_advanced_options",
			),
			array(
				'title'    => __( 'Delete notes', 'product-notes-for-woocommerce' ),
				'desc'     => '<span style="color:red;">' . __( 'Delete', 'product-notes-for-woocommerce' ) . '</span>',
				'desc_tip' => __( 'Deletes all notes for all products.', 'product-notes-for-woocommerce' ) . ' ' .
					__( 'Check the box and save changes to delete notes.', 'product-notes-for-woocommerce' ) . ' ' .
					__( 'Please note that there is no undo for this action.', 'product-notes-for-woocommerce' ),
				'id'       => "alg_wc_pn_{$private_or_public}_delete_all",
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => "alg_wc_pn_{$private_or_public}_advanced_options",
			),
		);

		return array_merge( $general_settings, $frontend_settings, $backend_settings, $advanced_settings );
	}

}

endif;
